import { EventEmitter, OnInit, ChangeDetectorRef, OnChanges, SimpleChanges, TemplateRef } from '@angular/core';
import { UntypedFormGroup } from '@angular/forms';
import { FormlyFieldConfig, FormlyFormOptions } from '@ngx-formly/core';
import * as qs from 'qs';
import { SDSFormlyUpdateComunicationService } from './service/sds-filters-comunication.service';
import { SDSFormlyUpdateModelService } from './service/sds-filter-model-update.service';
import { Subject } from 'rxjs';
import { ReadonlyDataType } from '../formly/services/formly-utils.service';
import { SdsDialogRef, SdsDialogService } from '@gsa-sam/components';
import * as i0 from "@angular/core";
export declare class SdsFiltersComponent implements OnInit, OnChanges {
    formlyUpdateComunicationService: SDSFormlyUpdateComunicationService;
    private formlyDialogService;
    private cdr;
    private filterUpdateModelService;
    horizontalFiltersDialogTemplate: TemplateRef<any>;
    /**
     * Pass in a Form Group for ReactiveForms Support
     */
    form: UntypedFormGroup;
    /**
     *  Fields are used to configure the UI components
     */
    fields: FormlyFieldConfig[];
    /**
     *  Model used to display the filter values.
     */
    model: any;
    /**
     *    Options for the form.
     */
    options: FormlyFormOptions;
    /**
     *  Emit results when model updated
     * To enable History Tracking
     *  If advanced filters dialog should be displayed -- defaults to false
     */
    advancedFilters: boolean;
    /**
     * Sort the filters by alphabetical order
     */
    sortMoreFilterBy: string;
    /**
     * Show option to include inactive filter values
     */
    isInactiveValueFieldShown: boolean;
    /**
     * Timer id for the timer awaiting the service call for more typeing
     */
    isHistoryEnable: boolean;
    /**
     * To get clean model without null and empty
     */
    getCleanModel: boolean;
    /**
     * Default values to reset form to when reset is done
     * If not passed in, then default values will be values
     * assigned to the model input during component init
     * or defaultValue provided in formly config
     */
    defaultModel: any;
    /**
     * Toggle layout for filters - when horizontal is toggled,
     * the reset and more filters are placed in top right corner
     */
    horizontal: boolean;
    /**
     * Toggle displaying chips for selected filter values. By default this is toggled off
     * in normal situations. When horizontal setting is turned on, then chip display is
     * also toggled on by default
     */
    displayChips: boolean;
    /**
     * This is to display the search field inside horizontal filter
     */
    enableSearchfield: boolean;
    /**
     * This is to update the place holder text for the sds-search.
     */
    private _horizontalSearchPlaceholder;
    get horizontalSearchPlaceholder(): string;
    set horizontalSearchPlaceholder(val: string);
    /**
     * Switch to show/hide the reset all button
     * @default true
     */
    showReset: boolean;
    /**
     *  Emit results when model updated
     */
    filterChange: EventEmitter<object>;
    showInactiveFiltersChange: EventEmitter<boolean>;
    resetClicked: EventEmitter<any>;
    chips: ReadonlyDataType[];
    dialogRef: SdsDialogRef<any>;
    /**
     * Default search field configuration for the horizontal filter
     */
    searchField: FormlyFieldConfig;
    _modelSnapshot: any;
    unsubscribe$: Subject<void>;
    _isObj: (obj: any) => boolean;
    _isEmpty: (obj: any) => boolean;
    overwrite: (baseObj: any, newObj: any) => {};
    constructor(formlyUpdateComunicationService: SDSFormlyUpdateComunicationService, formlyDialogService: SdsDialogService, cdr: ChangeDetectorRef, filterUpdateModelService: SDSFormlyUpdateModelService);
    ngOnDestroy(): void;
    ngOnInit(): void;
    ngOnChanges(changes: SimpleChanges): void;
    /**
     * This is for getting the model which has a value.
     */
    checkForHide(): void;
    /**
     * Recursively iterate over each field as well as potential field groups of the field
     * to find a field with the given key. Returns the field if found, otherwise returns null.
     * @param fields - The list of formly fields to search for the given key
     * @param key - The key of the formly field config to search for
     */
    private findFieldInFieldGroup;
    onModelChange(change: any): void;
    onResetClicked(): void;
    updateChange(change: any): void;
    convertToParam(filters: any): {};
    getUrlParams(queryString: any): {};
    convertToModel(filters: any): {};
    /**
     * Parser for qs.parse - if input string is true / false,
     * convert to boolean value, otherwise use default decoder
     */
    cleanModelParser(str: string, decoder: qs.defaultDecoder, charset: string, type: 'key' | 'value'): string | boolean;
    handleInactiveFilterChange(inactiveFilterValue: boolean): void;
    openDialog(): void;
    close(): void;
    applyDialogFilters(): void;
    /**
     * Converts all popover type fields to accordion and unhides any hidden fields
     * so that they can be displayed in filter dialog during resposive mode for
     * horizontal filters
     * @param fields
     */
    private removePopoverGroup;
    /**
     * Create chips to display for horizontal filters based on current model
     * and formly field config
     * @param model
     * @param fields
     */
    private generateChips;
    /**
     * Removing a certain chip from UI is the same as applying a change to the form, so
     * this should update the form control. We can find the field to update based on the chip's
     * formly key and what values to update to based on values of existing chips with the same key
     * @param chip
     * @returns
     */
    removeChip(chip: ReadonlyDataType): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<SdsFiltersComponent, [{ optional: true; }, null, null, { optional: true; }]>;
    static ɵcmp: i0.ɵɵComponentDeclaration<SdsFiltersComponent, "sds-filters", never, { "form": { "alias": "form"; "required": false; }; "fields": { "alias": "fields"; "required": false; }; "model": { "alias": "model"; "required": false; }; "options": { "alias": "options"; "required": false; }; "advancedFilters": { "alias": "advancedFilters"; "required": false; }; "sortMoreFilterBy": { "alias": "sortMoreFilterBy"; "required": false; }; "isInactiveValueFieldShown": { "alias": "isInactiveValueFieldShown"; "required": false; }; "isHistoryEnable": { "alias": "isHistoryEnable"; "required": false; }; "getCleanModel": { "alias": "getCleanModel"; "required": false; }; "defaultModel": { "alias": "defaultModel"; "required": false; }; "horizontal": { "alias": "horizontal"; "required": false; }; "displayChips": { "alias": "displayChips"; "required": false; }; "enableSearchfield": { "alias": "enableSearchfield"; "required": false; }; "horizontalSearchPlaceholder": { "alias": "horizontalSearchPlaceholder"; "required": false; }; "showReset": { "alias": "showReset"; "required": false; }; }, { "filterChange": "filterChange"; "showInactiveFiltersChange": "showInactiveFiltersChange"; "resetClicked": "resetClicked"; }, never, never, false, never>;
}
