import { ChangeDetectorRef, ElementRef, EventEmitter, QueryList, SimpleChanges, TemplateRef } from '@angular/core';
import { FormGroup } from '@angular/forms';
import { ActivatedRoute, Router } from '@angular/router';
import { FormlyFieldConfig, FormlyFormOptions } from '@ngx-formly/core';
import { Observable } from 'rxjs';
import * as i0 from "@angular/core";
export declare class SdsStepHeaderComponent {
    static ɵfac: i0.ɵɵFactoryDeclaration<SdsStepHeaderComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<SdsStepHeaderComponent, "[sdsStepHeader]", never, {}, {}, never, ["*"], false, never>;
}
export declare class SdsStepFooterComponent {
    static ɵfac: i0.ɵɵFactoryDeclaration<SdsStepFooterComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<SdsStepFooterComponent, "[sdsStepFooter]", never, {}, {}, never, ["*"], false, never>;
}
export declare class SdsStepComponent {
    _stepper: SdsStepper;
    private _el;
    private _document;
    /**
     * References to Any children this step might contain
     */
    children: QueryList<SdsStepComponent>;
    /**
     * Content of step - either a formly field or custome template
     */
    content: TemplateRef<any>;
    /**
     * Custom template reference for this step. If both custom template and field
     * config are provided, then only the custom template will be displayed
     */
    stepTemplate: TemplateRef<any>;
    /**
     * Required when stepTemplate is defined - provides ways to check
     * if the custom template step is valid
     */
    stepValidationFn: (model: any, field?: FormlyFieldConfig) => boolean | Observable<boolean> | void;
    /**
     * Human readable label text for this step
     */
    text: string;
    /**
     * Id for step - auto generated if none is provided
     */
    id: string;
    /**
     * Whether the step is selected or not
     */
    selected: boolean;
    /**
     * Formly fields to display for this step
     */
    fieldConfig?: FormlyFieldConfig;
    /**
     * Each step gets it's own options by default if not provided to determine whether to show error or not
     */
    options?: FormlyFormOptions;
    /**
     * Reference to data model to store any user input if the input. If not defined,
     * then user input data will be stored in a stepper level global model
     */
    model?: any;
    /**
     * Defines whether the step has validation issues or not
     */
    valid?: boolean | void;
    /**
     * Function for whether or not the step is hidden from users or not
     */
    hideFn?: (model: any, field?: FormlyFieldConfig) => boolean;
    hide?: boolean;
    /**
     * Defines whether current step is review step. Review steps are generally the last
     * step and contain culmination of user input throughout the steps in a readable format
     */
    isReview?: boolean;
    /**
     * Defines whether the step is an editable form or simply a label
     * @default true
     */
    editable: boolean;
    /**
     * Route to navigate to when the step is clicked. If none provided, then
     * navigation will only modify query parameter to clicked step's ID when clicked
     */
    route?: string;
    /**
     * Whether users should be allowed to navigate to this step or not
     */
    disabled?: boolean;
    validateOnBlur: boolean;
    form: FormGroup<{}>;
    /**
     * Emitted anytime user input changes in the step - only applicable if
     * step is a formly field config
     */
    modelChange: EventEmitter<any>;
    constructor(_stepper: SdsStepper, _el: ElementRef, _document: any);
    hasAllEmptyValues(obj: any): any;
    ngOnInit(): void;
    /**
     * Dispatch a custom event for parent stepper component to listen for on model change
     * as well as an output binded event emitter for application level components to listen
     * for if they wanted to listen at individual step level
     * @param $event - the updated model
     */
    onModelChange($event: any): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<SdsStepComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<SdsStepComponent, "sds-step", ["sdsStep"], { "stepTemplate": { "alias": "stepTemplate"; "required": false; }; "stepValidationFn": { "alias": "stepValidationFn"; "required": false; }; "text": { "alias": "text"; "required": false; }; "id": { "alias": "id"; "required": false; }; "selected": { "alias": "selected"; "required": false; }; "fieldConfig": { "alias": "fieldConfig"; "required": false; }; "options": { "alias": "options"; "required": false; }; "model": { "alias": "model"; "required": false; }; "valid": { "alias": "valid"; "required": false; }; "hideFn": { "alias": "hideFn"; "required": false; }; "hide": { "alias": "hide"; "required": false; }; "isReview": { "alias": "isReview"; "required": false; }; "editable": { "alias": "editable"; "required": false; }; "route": { "alias": "route"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; "validateOnBlur": { "alias": "validateOnBlur"; "required": false; }; }, { "modelChange": "modelChange"; }, ["children"], ["[sdsStepHeader]", "[sdsStepFooter]", "sds-step"], false, never>;
}
export declare class SdsStepper {
    private router;
    private activatedRoute;
    cdr: ChangeDetectorRef;
    stepTemplates: QueryList<SdsStepComponent>;
    /**
     * Singular global model to store user input for all steps. Alternatively,
     * users may pass in a model specifically to each sds-step and manage the data
     * modal separately
     */
    model: any;
    /**
     * Id of the step currently shown to users
     */
    currentStepId: string;
    /**
     * Mapping of step validity. This maps each step's id to a boolean value indicating
     * whether the step is valid or invalid. This maps defines valid/invalid icons
     * displayed in side nav
     */
    stepValidityMap: {
        [key: string]: boolean | undefined;
    };
    /**
     * Toggle custom error handling from user side. By default, errors are displayed
     * only on save click or when loading a pre-saved form with defined validity.
     * @default false
     */
    customErrorHandling: boolean;
    /** Whether the validity of previous steps should prevent navigating to next steps.
     * @default false
     */
    linear: boolean;
    /**
     * Unique identifier for the stepper. If none provided a default id will be used
     */
    id: string;
    /**
     * Configurable query parameter to use when keeping track of which
     * step the user is on from the URL. Useful when we'd want multiple
     * steppers in one page but don't want the query params to conflict
     * @default - sdsStepId
     */
    queryParamKey: string;
    /**
     * This is used to disable/enable the routing for the stepper
     * @default - true
     */
    isRouteEnabled: boolean;
    validateStepsOnInit: boolean | Array<string>;
    /**
     * Input to override the check for _isReviewAndSubmitDisabled truthyness
     */
    canReviewWithErrors: boolean;
    /**
     * Output event - emitted when save button is clicked
     */
    saveData: EventEmitter<{
        model: any;
        metadata: any;
    }>;
    /**
     * Output event - emitted when a step is changed, either through the
     *  navigation buttons at the bottom of the step or by clicking on a
     *  step in side panel
     */
    stepChange: EventEmitter<SdsStepComponent>;
    /**
     * Output event - emitted if the current step is a formly config.
     *  Outputs whenever a model change occurs from the formly field
     */
    modelChange: EventEmitter<any>;
    /**
     * Reference to step currently selected and displayed to the user
     */
    selectedStep: SdsStepComponent;
    /**
     * Index of currently selected step in the flatSteps array
     */
    selectedStepIndex: number;
    /**
     * A flattened list of steps - steps with children are placed after their parent
     * in the list
     */
    flatSteps: SdsStepComponent[];
    /**
     * Switch that toggles on if and only if all steps in the flattned list of steps
     * are seen as valid in the validity map
     */
    _isReviewAndSubmitDisabled: boolean;
    /**
     * Event emitted by sds-step component whenever a model change
     * occurs. Emits the modelChange event. This can be useful if
     * users want to attach a listener for any model change in overall
     * steps rather than listening for model change in each individual step
     * @param $event
     */
    onModelChange($event: CustomEvent): void;
    constructor(router: Router, activatedRoute: ActivatedRoute, cdr: ChangeDetectorRef);
    ngOnChanges(changes: SimpleChanges): void;
    ngAfterViewInit(): void;
    ngAfterContentInit(): void;
    getFlatSteps(stepTemplates: QueryList<SdsStepComponent>): SdsStepComponent[];
    /**
     * Change currently selected step
     * @param stepId - The id of step to change to
     * @param incrementor - Optional input - Either a 1 or -1. When a value of 1
     *  is provided, then the step to change to will be the next step from the input step
     *  given. When a value of -1 is provided, then the selected step will be the step
     *  previous to the provided step
     */
    changeStep(stepId: string, incrementor?: number, blockValidity?: boolean): Promise<void>;
    /**
     * Enables validation error display for a given step
     * @param step
     */
    private toggleOnValidationForStep;
    onNextStep(): void;
    onPreviousStep(): void;
    /**
     * Called through sdsStepperSave button - updates validity of the current step
     * and toggles error display. Emits saveData event.
     */
    onSaveClicked(): Promise<void>;
    /**
     * Gets all steps that are not hidden
     * @param steps
     */
    getDisplayedSteps(steps: QueryList<SdsStepComponent>): SdsStepComponent[];
    /**
     * Used while in linear mode. All steps that are in the step validity and are valid
     * map should be enabled until we find the first step that is invalid.
     * Then all steps from that point on should be disabled
     *
     * @returns the index of the last valid step
     */
    private evaluateIncompleteForms;
    private checkReviewAndSubmit;
    private updateValidity;
    /**
     * Updates validity of a given step. If a synchronous stepValidationFn is provided
     * for the step, then that method is given priority over the step's formly form.
     * If a forceValidationValue is given, then the step's validation value will be set
     * to the value provided
     * @param currentStep - step to update validation for
     * @param forceValidationValue - true or false -
     *  if true, step's validity will be force set to true
     *  if false, step's validity will be force set to false
     * @returns
     */
    updateValidation(currentStep: SdsStepComponent, forceValidationValue?: boolean): Promise<void>;
    private isFormEmpty;
    private getCleanObject;
    static ɵfac: i0.ɵɵFactoryDeclaration<SdsStepper, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<SdsStepper, "[sdsStepper]", ["sdsStepper"], { "model": { "alias": "model"; "required": false; }; "currentStepId": { "alias": "currentStepId"; "required": false; }; "stepValidityMap": { "alias": "stepValidityMap"; "required": false; }; "customErrorHandling": { "alias": "customErrorHandling"; "required": false; }; "linear": { "alias": "linear"; "required": false; }; "id": { "alias": "id"; "required": false; }; "queryParamKey": { "alias": "queryParamKey"; "required": false; }; "isRouteEnabled": { "alias": "isRouteEnabled"; "required": false; }; "validateStepsOnInit": { "alias": "validateStepsOnInit"; "required": false; }; "canReviewWithErrors": { "alias": "canReviewWithErrors"; "required": false; }; }, { "saveData": "saveData"; "stepChange": "stepChange"; "modelChange": "modelChange"; }, ["stepTemplates"], never, false, never>;
}
