import { FormlyFieldConfig } from '@ngx-formly/core';
import { SdsFormlyTypes } from '../models/formly-types';
import { ReadonlyOptions } from '../readonly/readonly-options.model';
import * as i0 from "@angular/core";
export interface ReadonlyDataType {
    formlyType: SdsFormlyTypes;
    label: string;
    value: any;
    readonlyOptions: ReadonlyOptions;
    formlyKey: string;
}
export declare class FormlyUtilsService {
    /**
     * Set readonly mode of a formly field config list. Toggles all field config with defined
     * props property's readonlyMode to given value
     * @param readonlyMode - if true, readonly mode will be turned on, if false, readonly mode will be turned off
     * @param fields - The list of fields to toggle readonly mode on
     */
    static setReadonlyMode(readonlyMode: boolean, fields: FormlyFieldConfig[]): void;
    /**
     * Parses a formly field config and returns a list of items that readonly container component would accept.
     * This is used when you have field configs and the model, but would like to use components for readonly display
     * rather than formly. props must be defined for the field in order to convert.
     * @param fields - The list of fields to parse
     * @param model - Contains the values for given fields
     * @param options - Additional cofiguration options
     * options:
     *  convertAll - By default any fields with a type not in SdsFormlyType will be ignored.
     *               Turn this on to include fields with no type or type not in SdsFormlyType.
     */
    static formlyConfigToReadonlyData(fields: FormlyFieldConfig[], model: any, options?: {
        convertAll: boolean;
    }): ReadonlyDataType[];
    private static _setReadonlyMode;
    private static _formlyConfigToReadonlyData;
    static ɵfac: i0.ɵɵFactoryDeclaration<FormlyUtilsService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<FormlyUtilsService>;
}
